# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.2.0

import winrt.system
from winrt import _winrt_windows_management_core

__all__ = [
    "ApplicationDataManager",
]

ApplicationDataManager = _winrt_windows_management_core.ApplicationDataManager
